@@ -46,11 +46,15 @@ Engine::Engine(UPlay* parent)
 	// media
 	connect(mediaObject,SIGNAL(finished()),SLOT(playEnded()));
 	connect(mediaObject,SIGNAL(tick(qint64)),SLOT(refreshPlayedTime()));
+	
+	connect(mediaObject, SIGNAL(stateChanged(Phonon::State, Phonon::State)),
+				    this, SLOT(currentInfosUpdated(Phonon::State, Phonon::State)));
 
 	listMedias.clear();
 	
 	// default value
 	currentPlayedMedia = -1;
+	lastUpdated = -1;
 }
 
 Engine::~Engine()
@@ -90,7 +94,7 @@ Engine::stop()
 		parent->ui->getPlaylist().setBold(currentPlayedMedia,false);
 		currentPlayedMedia = -1;
 		parent->ui->getControls().setPlayIcon(Phonon::PlayingState);
-		parent->ui->setInfos("\n","00:00");
+		parent->ui->setInfos("\n");
 		currentTime->setText("0:00");
 		totalTime->setText(" / 0:00");
 		parent->ui->setWindowTitle("NecroPlayer");
@@ -103,7 +107,7 @@ Engine::stop()
 int
 Engine::play(int row)
 {
-	if (currentPlayedMedia != -1 && row == -1)
+  	if (currentPlayedMedia != -1 && row == -1)
 	{
 		switch (mediaObject->state())
 		{	
@@ -125,32 +129,9 @@ Engine::play(int row)
 	}
 	else
 	{
-		if (row == -1)
-		{
-			// TODO
-			row = 0;
-		}
-		if (row <= listMedias.count())
-		{
-			// Get infos
-			Media media = getInfos(row);
 
-			QString s;
-			// If the file doesn't have infos, use filename instead
-			if (media.artist.isEmpty())
-			{
-				s = media.title + "\n";
-				parent->ui->setWindowTitle(media.title);
-			}
-			else
-			{
-				s = media.artist + "\n" + media.title;	
-				parent->ui->setWindowTitle(media.artist+" - "+ media.title);
-				
-			}
-			
-			// Set the label, display a tray message
-			parent->ui->setInfos(s,media.totalTime);
+		if (row < listMedias.count())
+		{
 
 			// preparing reading
 			mediaObject->setCurrentSource(listSources[row]);
@@ -158,7 +139,6 @@ Engine::play(int row)
 			mediaObject->setTransitionTime(1000);
 			currentTime->setText("0:00");
 			seekSlider->setMediaObject(mediaObject);
-			totalTime->setText(" / " + media.totalTime);
 
 			if (currentPlayedMedia > -1)
 			{
@@ -169,6 +149,8 @@ Engine::play(int row)
 
 			// go
 			mediaObject->play();
+			
+			//totalTime->setText(" / 0:00");
 			parent->ui->getControls().setPlayIcon(Phonon::PausedState);
 
 		}
@@ -176,7 +158,6 @@ Engine::play(int row)
 		{
 			row = -1;
 		}
-
 	}
 
 	return row;
@@ -187,29 +168,61 @@ void Engine::addMedia(QStringList files)
 	if (files.isEmpty())
          return;
 	
-	int index = listSources.size();
+	//int index = listSources.size();
+	QFileInfo fi;
+	Media tmp_media;
+	 
 	foreach (QString string, files) 
 	{
 	  Phonon::MediaSource source(string);
-
 	  listSources.append(source);
-	  listUris.append(string);  
+	  listUris.append(string); 
+	  fi.setFile(string);
+	  parent->ui->addItem(fi.fileName());
+	  tmp_media.title=fi.fileName();
+	  tmp_media.artist="";
+	  tmp_media.album="";
+	  listMedias.append(tmp_media);
+	  
 	}
 	
 	if (!listSources.isEmpty())
 	{
-	  int index_cur = listSources.indexOf(mediaObjectForMetaInfos->currentSource());
+	 //  int index_cur = listSources.indexOf(mediaObjectForMetaInfos->currentSource());
 	 // qDebug()<<"index_cur: "<<index_cur;
 	 // qDebug()<<"index: "<<index;
-	  if (index_cur==index-1) //metaInfos not busy
-	    mediaObjectForMetaInfos->setCurrentSource(listSources.at(index));
+	 // if (index_cur==index-1) //metaInfos not busy
+	 //   mediaObjectForMetaInfos->setCurrentSource(listSources.at(index));
 	}
 }
 
+
+void Engine::startMetaUpdater(bool reload)
+{
+  	if ((!listSources.isEmpty())&&(parent->config->useTags)&&(!parent->config->updateOnPlay))
+	{
+	  if(reload)
+	  {
+	    mediaObjectForMetaInfos->setCurrentSource(listSources.at(0));
+	  }
+	  else
+	  {
+	    int index_cur = listSources.indexOf(mediaObjectForMetaInfos->currentSource());
+	    if(index_cur==lastUpdated)
+	    {
+	      mediaObjectForMetaInfos->setCurrentSource(listSources.at(lastUpdated+1));
+	    }
+	  }
+	}
+  
+}
+
 void
 Engine::refreshPlayedTime()
 {
 	currentTime->setText(Engine::msToString(mediaObject->currentTime()));
+//	totalTime->setText(" / " + Engine::msToString(mediaObject->totalTime()));
+	
 }
 
 Media
@@ -268,9 +281,11 @@ Engine::metaInfosUpdated(Phonon::State newState, Phonon::State oldState)
 	else
 	  result = media.artist + " - " + media.title;
 	
-	parent->ui->addItem(result);
-	listMedias.append(media);
-	
+	parent->ui->changeItem(result, listSources.indexOf(mediaObjectForMetaInfos->currentSource()));
+	listMedias.replace(listSources.indexOf(mediaObjectForMetaInfos->currentSource()),media);
+	//parent->ui->addItem(result);
+	//listMedias.append(media);
+	lastUpdated=listSources.indexOf(mediaObjectForMetaInfos->currentSource());
 	int index = listSources.indexOf(mediaObjectForMetaInfos->currentSource()) + 1;
 	if (listSources.size() > index) 
 	{
@@ -279,6 +294,67 @@ Engine::metaInfosUpdated(Phonon::State newState, Phonon::State oldState)
 
 }
 
+void Engine::currentInfosUpdated(Phonon::State newState, Phonon::State oldState)
+{
+   //qDebug()<<"=======>oldState: "<<oldState;
+   //qDebug()<<"=======>newState: "<<newState;
+  if (newState == Phonon::PlayingState )
+  {
+    totalTime->setText(" / " + Engine::msToString(mediaObject->totalTime()));
+  
+  
+  //bool updateMetaOnPlay=true;
+  
+    if ((parent->config->useTags)&&(parent->config->updateOnPlay))
+    {
+      if (mediaObject->currentSource().type() != Phonon::MediaSource::Invalid)
+      {
+	  QMap<QString, QString> metaData = mediaObject->metaData();
+	  Media media;
+	
+	  media.title = metaData.value("TITLE");
+	  media.artist = metaData.value("ARTIST");
+	  media.album = metaData.value("ALBUM");
+	  media.totalTime = Engine::msToString(mediaObject->totalTime());
+	
+	  if(media.title!="")
+	  {
+	    QString result;
+	    result = media.artist + " - " + media.title;
+	    parent->ui->changeItem(result, currentPlayedMedia);
+	    listMedias.replace(currentPlayedMedia,media);
+	    //qDebug()<<currentPlayedMedia;
+	    //qDebug()<<listSources.indexOf(mediaObject->currentSource());
+	  
+	  }
+      }        
+    }
+  
+  
+    // Get infos
+    Media media = getInfos(currentPlayedMedia);
+
+    QString s;
+
+    if (media.artist.isEmpty())
+    {
+      s = media.title + "\n";
+      parent->ui->setWindowTitle(media.title);
+    }
+    else
+    {
+      s = media.artist + "\n" + media.title;
+      parent->ui->setWindowTitle(media.artist+" - "+ media.title);
+    }
+
+    parent->ui->setInfos(s);
+    
+  }
+  
+  
+  //mediaObject
+  
+}
 
 void
 Engine::playEnded()
