@@ -7,25 +7,31 @@
 UI::UI(UPlay* parent, QString& musicPath)
 {
 	this->parent = parent;
+	
+	setupActions();
+	setupMenus();
 
 	//QStyle* style = this->style();
 
 	// Initialize the random
 	qsrand(time(NULL));
-	random = false;
+	
+	areaW = new QWidget();
 	
 	infosArea = new QScrollArea();
 	infosArea->setWidgetResizable(true);
 	infosArea->setAlignment(Qt::AlignCenter);
 // 	infosLayout=new QVBoxLayout;
 	
-	infosSong = new QLabel("\n");
-	//infosSong->setText("\n");
+	infosSong = new QLabel(areaW);
+	infosSong->setText("\n");
 	infosSong->setAlignment(Qt::AlignCenter);
 	//infosSong->setFrameStyle(QFrame::StyledPanel);
-	infosLayout=new QVBoxLayout;
+	infosLayout=new QVBoxLayout(areaW);
 	infosLayout->addWidget(infosSong);
-	infosArea->setLayout(infosLayout);
+	//infosLayout->setSizeConstraint(QLayout::SetNoConstraint);
+	//infosArea->setLayout(infosLayout);
+	infosArea->setWidget(areaW);
 	//infosSong->setWordWrap(true);
 	
 	// Controls
@@ -35,13 +41,13 @@ UI::UI(UPlay* parent, QString& musicPath)
 	// Folder
 	folder = new UIFolder(parent,musicPath);
 	// Settings
-	settings = new UISettings(parent, musicPath);
+	//settings = new UISettings(parent, musicPath);
 
 	// Tab
 	tab = new QTabWidget;
-	tab->addTab(playlist, "Playlist");
-	tab->addTab(folder, "Folder");
-	tab->addTab(settings,"Settings");
+	tab->addTab(playlist, tr("Playlist"));
+	tab->addTab(folder, tr("Files"));
+	//tab->addTab(settings,"Settings");
 
 	// Layouts
 	mainLayout = new QHBoxLayout;
@@ -74,7 +80,17 @@ UI::UI(UPlay* parent, QString& musicPath)
 
 	// UI
 	//setMinimumSize(250,80);
-	setLayout(mainLayout);
+	//setLayout(mainLayout);
+	mainW = new QWidget();
+	mainW->setLayout(mainLayout);
+	setCentralWidget(mainW);
+	
+	tab->setVisible(!parent->config->simpleView);
+	//adjustSize();
+	
+	settingsdialog = new SettingsDialog();
+	connect(settingsdialog, SIGNAL(accepted()), this, SLOT(settingsDialogAccepted()));
+
 	setWindowTitle("NecroPlayer");
 	show();
 }
@@ -91,8 +107,8 @@ UI::~UI()
 		delete controls; controls = NULL;
 	if (folder)
 		delete folder; folder = NULL;
-	if (settings)
-		delete settings; settings = NULL;
+// 	if (settings)
+// 		delete settings; settings = NULL;
 	if (tab)
 		delete tab;
 	if (inf_seek)
@@ -103,6 +119,9 @@ UI::~UI()
 		delete ctrlLayout;
 	if (mainLayout)
 		delete mainLayout;
+	if (mainW)
+		delete mainW;
+
 	
 	
 }
@@ -111,14 +130,14 @@ void
 UI::toggleInterface()
 {
 	tab->setVisible(!tab->isVisible());
-	adjustSize();
-}
+	if(tab->isVisible())
+	    parent->config->simpleView=false;
+	else
+	    parent->config->simpleView=true;
 	
-// void
-// UI::dragEnterEvent(QDragEnterEvent *event)
-// {
-// 	event->acceptProposedAction();
-// }
+	//adjustSize();
+}
+
 
 void
 UI::clearPlaylist()
@@ -126,31 +145,12 @@ UI::clearPlaylist()
 	playlist->clearPlaylist(); 
 }
 
-// void
-// UI::dropEvent(QDropEvent* event)
-// {
-// 	QList<QUrl> urlList;
-// 	QStringList files;
-// 
-// 	// if dropped data = url
-// 	if (event->mimeData()->hasUrls())
-// 	{
-// 		event->acceptProposedAction();
-// 		// we retrieve data
-// 		urlList = event->mimeData()->urls();
-// 
-// 		for (int i = 0; i < urlList.size(); i++)
-// 		{
-// 			files.append(urlList[i].toString());
-// 		}
-// 		playlistAdd(files);
-// 	}	
-// }
 
 void
 UI::playlistAdd(QStringList ss)
 {
 	parent->engine->addMedia(ss);
+	parent->engine->startMetaUpdater();
 }
 
 void
@@ -159,6 +159,11 @@ UI::addItem(QString s)
 	playlist->addItem(s);
 }
 
+void UI::changeItem(QString s, int row)
+{
+	playlist->changeItem(s,row);
+}
+
 void
 UI::play()
 {
@@ -183,28 +188,47 @@ UI::prev()
 	parent->prev();
 }
 
-void
-UI::tQuit()
-{
-	parent->exit();
-}
 
 void
-UI::setInfos(QString s,QString totalTime)
+UI::setInfos(QString s)
 {
 	infosSong->setText(s);
 }
 
-void
-UI::switchHide()
+void UI::setupActions()
 {
-	hiden = !hiden;
-	if (hiden)
-	{
-		hide();
-	}
-	else
-	{
-		show();
-	}
+  settingsAction = new QAction(tr("Settings"),this);
+  connect(settingsAction, SIGNAL(triggered()), this, SLOT(settingsDialogOpen()));
+  
+  
 }
+
+void UI::setupMenus()
+{
+  settingsMenu = menuBar()->addMenu(tr("Settings"));
+  settingsMenu->addAction(settingsAction);
+  
+}
+
+void UI::settingsDialogOpen()
+{
+  settingsdialog->setConfig(parent->config);
+  settingsdialog->show();
+  
+}
+
+void UI::settingsDialogAccepted()
+{
+  //qDebug()<<"Setting Dialog Accepted";
+  bool tmpUseTags=parent->config->useTags;
+  settingsdialog->getConfig(parent->config);
+  if((tmpUseTags==false)&&(parent->config->useTags==true))
+    parent->engine->startMetaUpdater(true);
+  
+  folder->refreshWithNewMusicPath(parent->config->musicFolder);
+  
+  
+}
+
+
+
